@@ -1,4 +1,11 @@
 package MooseX::Declare::Syntax::KeywordHandling;
+BEGIN {
+  $MooseX::Declare::Syntax::KeywordHandling::AUTHORITY = 'cpan:FLORA';
+}
+BEGIN {
+  $MooseX::Declare::Syntax::KeywordHandling::VERSION = '0.34';
+}
+# ABSTRACT: Basic keyword functionality
 
 use Moose::Role;
 use Moose::Util::TypeConstraints;
@@ -11,22 +18,26 @@ use aliased 'MooseX::Declare::Context';
 
 use namespace::clean -except => 'meta';
 
+
 requires qw(
     parse
 );
 
+
 has identifier => (
     is          => 'ro',
     isa         => subtype(as 'Str', where { /^ [_a-z] [_a-z0-9]* $/ix }),
     required    => 1,
 );
 
+
 sub get_identifier { shift->identifier }
 
 sub context_class { Context }
 
 sub context_traits { }
 
+
 sub setup_for {
     my ($self, $setup_class, %args) = @_;
 
@@ -54,6 +65,7 @@ sub setup_for {
     return 1;
 }
 
+
 sub parse_declaration {
     my ($self, $caller_file, $args, @ctx_args) = @_;
 
@@ -85,9 +97,13 @@ sub parse_declaration {
     return $self->parse($ctx);
 }
 
+
 1;
 
 __END__
+=pod
+
+=encoding utf-8
 
 =head1 NAME
 
@@ -105,14 +121,6 @@ in L<MooseX::Declare>.
 This is the name of the actual keyword. It is a required string that is in
 the same format as a usual Perl identifier.
 
-=head1 REQUIRED METHODS
-
-=head2 parse
-
-  Object->parse (Object $context)
-
-This method must implement the actual parsing of the keyword syntax.
-
 =head1 METHODS
 
 =head2 get_identifier
@@ -139,19 +147,112 @@ the return value of that method.
 This simply creates a new L<context|MooseX::Declare::Context> and passes it
 to the L</parse> method.
 
+=head1 REQUIRED METHODS
+
+=head2 parse
+
+  Object->parse (Object $context)
+
+This method must implement the actual parsing of the keyword syntax.
+
 =head1 SEE ALSO
 
-=over
+=over 4
 
-=item * L<MooseX::Declare>
+=item *
 
-=item * L<MooseX::Declare::Context>
+L<MooseX::Declare>
+
+=item *
+
+L<MooseX::Declare::Context>
 
 =back
 
-=head1 AUTHOR, COPYRIGHT & LICENSE
+=head1 AUTHORS
 
-See L<MooseX::Declare>
+=over 4
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Ash Berlin <ash@cpan.org>
+
+=item *
+
+Chas. J. Owens IV <chas.owens@gmail.com>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Devin Austin <dhoss@cpan.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@cpan.org>
+
+=item *
+
+Justin Hunter <justin.d.hunter@gmail.com>
+
+=item *
+
+Matt Kraai <kraai@ftbfs.org>
+
+=item *
+
+Michele Beltrame <arthas@cpan.org>
+
+=item *
+
+Nelo Onyiah <nelo.onyiah@gmail.com>
+
+=item *
+
+nperez <nperez@cpan.org>
+
+=item *
+
+Piers Cawley <pdcawley@bofh.org.uk>
+
+=item *
+
+Rafael Kitover <rkitover@io.com>
+
+=item *
+
+Robert 'phaylon' Sedlacek <rs@474.at>
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Tomas Doran <bobtfish@bobtfish.net>
+
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Florian Ragwitz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
